@@ -1,5 +1,5 @@
 from collections import OrderedDict
-from typing import Optional, Sequence
+from typing import Optional, Sequence, List
 from django.conf import settings
 from django.contrib import admin
 from django.contrib.auth.models import User
@@ -7,7 +7,6 @@ from django.http import HttpRequest
 from django.urls import reverse
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
-from jutil.model import get_model_field_label_and_value
 from django.utils.translation import gettext_lazy as _
 from django.contrib.admin.models import CHANGE
 from django.template.response import TemplateResponse
@@ -60,6 +59,26 @@ def admin_log(instances: Sequence[object],
             )
 
 
+def admin_log_changed_fields(obj: object, field_names: Sequence[str], who: Optional[User] = None, **kwargs):
+    """
+    Logs changed fields of a model instance to admin log.
+    :param obj: Model instance
+    :param field_names: Field names
+    :param who: Who did the change. If who is None then User with username of settings.DJANGO_SYSTEM_USER (default: 'system') will be used
+    :param kwargs: Optional key-value attributes to append to message
+    :return:
+    """
+    from jutil.model import get_model_field_label_and_value  # noqa
+    fv: List[str] = []
+    for k in field_names:
+        label, value = get_model_field_label_and_value(obj, k)
+        fv.append('{}: "{}"'.format(label, value))
+    msg = ', '.join(fv)
+    if 'ip' in kwargs:
+        msg += " (IP {ip})".format(ip=kwargs.pop('ip'))
+    admin_log([obj], msg, who, **kwargs)  # type: ignore
+
+
 def admin_obj_url(obj: Optional[object], route: str = '', base_url: str = '') -> str:
     """
     Returns admin URL to object. If object is standard model with default route name, the function
@@ -169,13 +188,5 @@ class AdminLogEntryMixin:
     Mixin for logging Django admin changes of models.
     Call fields_changed() on change events.
     """
-
-    def fields_changed(self, field_names: Sequence[str], who: Optional[User], **kw):
-        fv_str = ''
-        for k in field_names:
-            label, value = get_model_field_label_and_value(self, k)
-            fv_str += '{}={}'.format(label, value) if not fv_str else ', {}={}'.format(label, value)
-
-        msg = "{class_name} id={id}: {fv_str}".format(
-            class_name=self._meta.verbose_name.title(), id=self.id, fv_str=fv_str)  # type: ignore
-        admin_log([who, self], msg, who, **kw)  # type: ignore
+    def fields_changed(self, field_names: Sequence[str], who: Optional[User] = None, **kwargs):
+        admin_log_changed_fields(self, field_names, who, **kwargs)
